@@ -1,5 +1,5 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
-### BEGIN LICENSE
+#
 # Copyright (C) 2011-2013 Marc Deslauriers <marc.deslauriers@canonical.com>
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -12,9 +12,9 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-### END LICENSE
+#
 
-from gi.repository import Gtk  # pylint: disable=E0611
+from gi.repository import Gtk
 
 from pasaffe_lib.helpersgui import get_builder
 
@@ -22,7 +22,6 @@ import gettext
 from gettext import gettext as _
 gettext.textdomain('pasaffe')
 
-# pylint: disable=E1101
 
 class NewPasswordDialog(Gtk.Dialog):
     __gtype_name__ = "NewPasswordDialog"
